# tests for basic login
import json
import pytest

from tests.rest import utils


@pytest.fixture
def tokens(client):
    request_dict = {
        "type": "user",
        "username": "admin",
        "password": "789789"
    }
    request_json = json.dumps(request_dict)
    response = client.post("/api/v1.0/auth/login", data=request_json,
                           headers={"content-type": "application/json"})
    data = utils.extract_data(response)
    return data


def test_login_user_valid(client):
    request_dict = {
        "type": "user",
        "username": "admin",
        "password": "789789"
    }
    request_json = json.dumps(request_dict)
    response = client.post("/api/v1.0/auth/login", data=request_json,
                           headers={"content-type": "application/json"})
    assert response.status_code == 200
    assert response.mimetype == "application/json"

    tokens = utils.extract_data(response)
    assert tokens.get('access_token')
    assert tokens.get('refresh_token')


def test_login_component_valid(client):
    request_dict = {
        "type": "component",
        "name": "executor",
        "secret": "executor_secret"
    }
    request_json = json.dumps(request_dict)
    response = client.post(
        "/api/v1.0/auth/login", headers={"content-type": "application/json"}, data=request_json)
    assert response.status_code == 200
    assert response.mimetype == "application/json"


def test_refresh_token(client, tokens: dict):
    headers = {
        "Content-Type": "application/json",
        "Authorization": "Bearer " + tokens['refresh_token']
    }
    response = client.post("/api/v1.0/auth/refresh", headers=headers)
    assert response.status_code == 200
    assert response.mimetype == "application/json"
    assert tokens.get('access_token')


def test_user_logout(client, tokens):
    headers = {
        "Content-Type": "application/json",
        "Authorization": "Bearer " + tokens['access_token']
    }
    response = client.post("/api/v1.0/auth/logout", headers=headers)
    assert response.status_code == 200
    assert response.mimetype == "application/json"
